import 'dart:math' as math;
import 'dart:typed_data';
import 'package:struct/struct.dart' as struct;
import 'package:struct/constants.dart';
import 'package:test/test.dart';

main() {
  test('pack and unpack max byte identity', () {
    var values = [unsignedByteMax];
    var buffer = struct.pack('B', values);
    var unpacked = struct.unpack('B', buffer);
    expect(unpacked.first, equals(unsignedByteMax));
  });

  test('pack and unpack min byte identity', () {
    var values = [unsignedByteMin];
    var buffer = struct.pack('B', values);
    var unpacked = struct.unpack('B', buffer);
    expect(unpacked.first, equals(unsignedByteMin));
  });

  test('unpack 4 bytes of 255 into unsigned integer', () {
    var values = [255, 255, 255, 255];
    var buffer = struct.pack('BBBB', values);
    var unpacked = struct.unpack('I', buffer);
    expect(unpacked[0], equals(unsignedIntMax));
  });

  test('unpack 4 bytes of 0 into unsigned integer', () {
    var values = [0, 0, 0, 0];
    var buffer = struct.pack('BBBB', values);
    var unpacked = struct.unpack('I', buffer);
    expect(unpacked[0], equals(0));
  });

  test('unpack 2 bytes into unsigned short', () {
    var values = [255, 255];
    var buffer = struct.pack('BB', values);
    var unpacked = struct.unpack('S', buffer);
    expect(unpacked[0], equals(unsignedShortMax));
  });

  test('unpack 8 bytes into unsigned long', () {
    var values = [255, 255, 255, 255, 255, 255, 255, 255];
    var buffer = struct.pack('BBBBBBBB', values);
    var unpacked = struct.unpack('L', buffer);
    expect(unpacked[0], equals(unsignedLongMax));
  });
}
